==> manage-3.1.0-39.jar: management/sqls/sale/filesquery/compreQuery.sql <==
select * from (
select
  u.f_userinfo_code,     --客户编号
  u.f_olduserinfo_code,	 --旧用户编号
  uf.f_userfiles_id,
  u.f_user_name,		 --客户名称
  u.f_user_phone,		 --客户电话
  address.f_residential_area,
  address.f_address,
  u.f_user_state,
  u.f_balance,
  uf.f_user_type,
  uf.f_gasproperties,
uf.f_usetype,
uf.f_usestate,
  sp.f_price_name,
  sp.value,

  u.f_used_name,
  u.f_rent_phone,
  u.f_rent_name,
  u.f_zuhu_phone,
  u.f_open_date,
  u.f_contract_id,
  u.f_is_mgq,
  u.f_insurance_end_date,
  u.f_send_usegas_card,
sp.f_price_type,
  u.f_comments,
  u.f_credentials,
  u.f_idnumber,
  u.f_createfile_date,
  u.f_createfile_person,
  u.f_depname,
  u.f_people_num,
  gb.f_meter_brand,
  gm.f_meter_style,
  gb.f_meter_type,

  uf.f_table_state,
  uf.f_initial_base,
  uf.f_meter_base,
  uf.f_total_usegas_amount,
  uf.f_total_gas,
  uf.f_total_fee,
  uf.f_meternumber,
  uf.f_metertitles,
  uf.f_inputtor,
  uf.f_position,
uf.f_meter_classify,
  uf.f_userfiles_address,
  uf.f_install_person,
  uf.f_install_date,
  uf.f_gas_person,
  uf.f_gas_date,
  uf.f_fire_state,
  uf.f_valve_state,
  uf.f_meter_book_num,
  uf.f_meter_book_sort,
  uf.f_card_id,

  uf.f_aroundmeter,
  uf.f_whether_hairpin,


  uf.f_balance_amount,
  s.f_min_operate_date,
  uf.f_times,
  uf.f_fillcard_times,
  s.f_sell_number,
  uf.f_hand_date,
  s.f_max_operate_date,
  uf.f_sendsuccess,
  uf.f_orgid,
  uf.f_depid,
  uf.f_operatorid,
  address.f_pcd_id
from t_userfiles uf
  LEFT JOIN  t_userinfo u
    on uf.f_userinfo_id = u.f_userinfo_id
  LEFT JOIN t_user_address address
    on uf.f_useraddress_id = address.id
  LEFT JOIN t_gasbrand gb
    on uf.f_gasbrand_id = gb.id
  LEFT JOIN t_gasmodel gm
    on uf.f_gasmodel_id = gm.id
  LEFT JOIN
  (    select s.id,f_price_id,f_price_name,f_price_type,
         s.f_price_type + (select ' ' + d.f_price_name + '阶:' + '单价' + cast(f_price as varchar) + ',上限' + cast(f_gas as varchar)
         from t_detailprice d where d.f_stairprice_id=s.id for xml path('')) value
         from t_stairprice s where s.f_state='有效' and getdate()>=f_perform_date and getdate()<=f_end_date
         group by s.id,s.f_price_type,f_price_id,f_price_name
  ) sp on uf.f_price_id = sp.f_price_id
  left join (
	select * from t_handplan h where id = (
		select max(id) from t_handplan where f_userfiles_id = h.f_userfiles_id and f_meter_state='已抄表' and f_hand_state='有效' group by f_userfiles_id
	)
  ) h on uf.f_userfiles_id = h.f_userfiles_id
  left join (
	select f_user_id,min(f_operate_date) f_min_operate_date,max(f_operate_date) f_max_operate_date,count(*) f_sell_number from t_sellinggas where f_state='有效' group by f_user_id
  ) s on uf.f_user_id=s.f_user_id
where  (f_user_state = '正常' or f_user_state='预备') and f_table_state != '换表' and f_table_state != '无效'
) u where  {condition}
order by f_userfiles_id desc

==> manage-3.1.0-44.jar: management/sqls/sale/filesquery/compreQuery.sql <==
select * from (
select
  u.f_userinfo_code,     --客户编号
  u.f_olduserinfo_code,	 --旧用户编号
  uf.f_userfiles_id,
  u.f_user_name,		 --客户名称
  u.f_user_phone,		 --客户电话
  address.f_residential_area,
  address.f_address,
  u.f_user_state,
  u.f_balance,
  uf.f_user_type,
  uf.f_gasproperties,
uf.f_usetype,
uf.f_usestate,
  sp.f_price_name,
  sp.value,

  u.f_used_name,
  u.f_rent_phone,
  u.f_rent_name,
  u.f_zuhu_phone,
  u.f_open_date,
  u.f_contract_id,
  u.f_is_mgq,
  u.f_insurance_end_date,
  u.f_send_usegas_card,
sp.f_price_type,
  u.f_comments,
  u.f_credentials,
  u.f_idnumber,
  u.f_createfile_date,
  u.f_createfile_person,
  u.f_depname,
  u.f_people_num,
  gb.f_meter_brand,
  gm.f_meter_style,
  gb.f_meter_type,

  uf.f_table_state,
  uf.f_initial_base,
  uf.f_meter_base,
  uf.f_total_usegas_amount,
  uf.f_total_gas,
  uf.f_total_fee,
  uf.f_meternumber,
  uf.f_metertitles,
  uf.f_inputtor,
  uf.f_position,
uf.f_meter_classify,
  uf.f_userfiles_address,
  uf.f_install_person,
  uf.f_install_date,
  uf.f_gas_person,
  uf.f_gas_date,
  uf.f_fire_state,
  uf.f_valve_state,
  uf.f_meter_book_num,
  uf.f_meter_book_sort,
  uf.f_card_id,
(case when bu.f_userinfo_id is null then '否'
	else  '是' end ) f_isband,
  uf.f_aroundmeter,
  uf.f_whether_hairpin,


  uf.f_balance_amount,
  s.f_min_operate_date,
  uf.f_times,
  uf.f_fillcard_times,
  s.f_sell_number,
  uf.f_hand_date,
  s.f_max_operate_date,
  uf.f_sendsuccess,
  uf.f_orgid,
  uf.f_depid,
  uf.f_operatorid,
  address.f_pcd_id
from t_userfiles uf
  LEFT JOIN  t_userinfo u
    on uf.f_userinfo_id = u.f_userinfo_id
  LEFT JOIN t_user_address address
    on uf.f_useraddress_id = address.id
  LEFT JOIN t_gasbrand gb
    on uf.f_gasbrand_id = gb.id
  LEFT JOIN t_gasmodel gm
    on uf.f_gasmodel_id = gm.id
  left join (select f_userinfo_id from  t_banduser group by f_userinfo_id) bu
  on bu.f_userinfo_id = uf.f_userinfo_id
  LEFT JOIN
  (    select s.id,f_price_id,f_price_name,f_price_type,
         s.f_price_type + (select ' ' + d.f_price_name + '阶:' + '单价' + cast(f_price as varchar) + ',上限' + cast(f_gas as varchar)
         from t_detailprice d where d.f_stairprice_id=s.id for xml path('')) value
         from t_stairprice s where s.f_state='有效' and getdate()>=f_perform_date and getdate()<=f_end_date
         group by s.id,s.f_price_type,f_price_id,f_price_name
  ) sp on uf.f_price_id = sp.f_price_id
  left join (
	select * from t_handplan h where id = (
		select max(id) from t_handplan where f_userfiles_id = h.f_userfiles_id and f_meter_state='已抄表' and f_hand_state='有效' group by f_userfiles_id
	)
  ) h on uf.f_userfiles_id = h.f_userfiles_id
  left join (
	select f_user_id,min(f_operate_date) f_min_operate_date,max(f_operate_date) f_max_operate_date,count(*) f_sell_number from t_sellinggas where f_state='有效' group by f_user_id
  ) s on uf.f_user_id=s.f_user_id
where  (f_user_state = '正常' or f_user_state='预备') and f_table_state != '换表' and f_table_state != '无效'
) u where  {condition}
order by f_userfiles_id desc
